<!--
SPDX-FileCopyrightText: 2026 Helge Eichhorn <git@helgeeichhorn.de>

SPDX-License-Identifier: MPL-2.0
-->

# lox-time

Time modelling tools for the [Lox](https://github.com/lox-space/lox) ecosystem, supporting
TAI, TT, TDB, TCB, TCG, UTC, and UT1 with femtosecond precision.

Part of [Lox – Oxidized Astrodynamics](https://github.com/lox-space/lox).
